@@ -12,6 +12,10 @@ class ParametersABC(ABC):
 
     """
 
+    def __init__(self, **kwargs):
+        for k, v in kwargs.items():
+            setattr(self, k, v)
+
     def to_dict(self, iterable="null"):
         """
         Recursive function that converts class to nested dictionary.
@@ -74,9 +78,13 @@ class ParametersABC(ABC):
         return cls(**params)
 
     @classmethod
-    @abstractmethod
-    def default(cls):
-        pass
+    def default(cls, **kwargs):
+        overriden_defaults = cls._defaults
+
+        for k, v in kwargs.items():
+            overriden_defaults[k] = v
+
+        return cls.from_dict(overriden_defaults)
 
 
 class ProcessABC(ABC):
